@@ -9,17 +9,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """UserStoragePlotter."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK, S_ERROR
 from DIRAC.AccountingSystem.private.Plotters.BaseReporter import BaseReporter
 
 from LHCbDIRAC.AccountingSystem.Client.Types.UserStorage import UserStorage
 
-__RCSID__ = "$Id$"
-
 
 class UserStoragePlotter(BaseReporter):
     """UserStoragePlotter as extension of BaseReporter."""
