@@ -18,10 +18,6 @@ here and assuming they work fine.
 
 IMPORTANT: the test MUST be pylint compliant !
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import mock
 import unittest
 
