@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """BKQuery is a class that decodes BK paths, queries the BK at a high level."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import sys
 import six
@@ -620,10 +614,9 @@ class BKQuery:
                     lfnsExcept = set()
                 if lfnsExcept:
                     gLogger.warn(
-                        "***** WARNING ***** Found %d files in BK query that will be \
-          excluded (file type in %s)!"
-                        % (len(lfnsExcept), str(exceptFiles))
+                        "***** WARNING ***** Found %d files in BK query that will be excluded!" % len(lfnsExcept)
                     )
+                    gLogger.verbose("Exclusion file types", str(exceptFiles))
                     gLogger.warn("                    If creating a transformation, set '--FileType ALL'")
                     lfns = lfns - lfnsExcept
                 else:
