@@ -8,10 +8,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 """Base Entity System Manager."""
 
 
@@ -19,9 +15,6 @@ import os
 from DIRAC import gLogger, S_OK, S_ERROR
 
 
-__RCSID__ = "$Id$"
-
-
 class BaseESManager(object):
     """Base Entity manager class."""
 
