@@ -9,13 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Help class."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 from DIRAC import gLogger, S_OK
 
-__RCSID__ = "$Id$"
-
 
 class Help(object):
     """Class for help."""
