@@ -9,9 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set of functions used by the DMS scripts."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import os
 import datetime
 
@@ -27,8 +24,6 @@ from LHCbDIRAC.BookkeepingSystem.Client.LHCB_BKKDBClient import LHCB_BKKDBClient
 bkClient = BookkeepingClient()
 jobEventInputStat = {}
 
-__RCSID__ = "$Id$"
-
 
 def executeFileMetadata(dmScript):
     """Get a list of LFNs, their BK metadata and print it out.
@@ -116,17 +111,14 @@ def executeFileMetadata(dmScript):
 
 def __buildPath(bkDict):
     """Build a BK path from the BK dictionary."""
-    return (
-        os.path.join(
-            "/" + bkDict["ConfigName"],
-            bkDict["ConfigVersion"],
-            bkDict["ConditionDescription"],
-            bkDict["ProcessingPass"][1:].replace("Real Data", "RealData"),
-            str(bkDict["EventType"]),
-            bkDict["FileType"],
-        )
-        + (" (Invisible)" if bkDict["VisibilityFlag"] == "N" else "")
-    )
+    return os.path.join(
+        "/" + bkDict["ConfigName"],
+        bkDict["ConfigVersion"],
+        bkDict["ConditionDescription"],
+        bkDict["ProcessingPass"][1:].replace("Real Data", "RealData"),
+        str(bkDict["EventType"]),
+        bkDict["FileType"],
+    ) + (" (Invisible)" if bkDict["VisibilityFlag"] == "N" else "")
 
 
 def executeFilePath(dmScript):
