@@ -9,15 +9,9 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_BKK_Client_BaseESManager."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 import LHCbDIRAC.BookkeepingSystem.Client.BaseESManager as moduleTested
 
-__RCSID__ = "$Id$"
-
 
 class BaseESManager_TestCase(unittest.TestCase):
     def setUp(self):
