@@ -10,10 +10,6 @@
 ###############################################################################
 """ pytest for BookkeepingClient
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access,missing-docstring,invalid-name
 
 import pytest
