@@ -9,19 +9,12 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_BKK_DB_OracleBookkeepingDB."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import mock
 
 import LHCbDIRAC.BookkeepingSystem.DB.OracleBookkeepingDB as moduleTested
 from LHCbDIRAC.BookkeepingSystem.DB.OracleDB import OracleDB
 from DIRAC.ConfigurationSystem.Client.Config import gConfig
 
-__RCSID__ = "$Id$"
-
-
 # mock_OracleDB = mock.Mock(spec=OracleDB)
 testClass = moduleTested.OracleBookkeepingDB
 # self.moduleTested.OracleDB = mock_OracleDB
