@@ -9,15 +9,10 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """It is used to test the Bookkeeping utilities."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 import unittest
 
 from LHCbDIRAC.BookkeepingSystem.DB.Utilities import enoughParams, _ONE, _TWO
 
-__RCSID__ = "$Id$"
-
 
 class UtilitiesTestCase(unittest.TestCase):
     def test_enoughParams(self):
