@@ -9,11 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """stores the jobs and its parameters."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
 
 
 class Job(object):
