@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """It stores the job related information."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.JobConfiguration import JobConfiguration
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.JobOption import JobOption
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.File import File
@@ -28,8 +24,6 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.Quality import Quality
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.QualityParameters import QualityParameters
 from DIRAC import gLogger
 
-__RCSID__ = "$Id$"
-
 
 class JobReader(object):
     """JobReader class."""
