@@ -9,14 +9,8 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """stores the replica readed from an xml."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import gLogger
 
-__RCSID__ = "$Id$"
-
 
 class Replica(object):
     """Replica class."""
