@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """It interprets the XML reports and make a job, file, or replica object."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from xml.parsers.expat import ExpatError
 from xml.dom.minidom import parse, parseString
 from DIRAC import gLogger, S_OK, S_ERROR
@@ -23,26 +19,7 @@ from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.FileParam import FilePara
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.Job.JobParameters import JobParameters
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.JobReader import JobReader
 from LHCbDIRAC.BookkeepingSystem.Service.XMLReader.ReplicaReader import ReplicaReader
-from LHCbDIRAC.BookkeepingSystem.DB.DataTakingConditionInterpreter import (
-    BeamEnergyCondition,
-    VeloCondition,
-    MagneticFieldCondition,
-    EcalCondition,
-    HcalCondition,
-    HltCondition,
-    ItCondition,
-    LoCondition,
-    MuonCondition,
-    OtCondition,
-    Rich1Condition,
-    Rich2Condition,
-    Spd_prsCondition,
-    TtCondition,
-    VeloPosition,
-    Context,
-)
-
-__RCSID__ = "$Id$"
+from LHCbDIRAC.BookkeepingSystem.DB.DataTakingConditionInterpreter import generateConditionDescription
 
 
 class XMLFilesReaderManager(object):
@@ -476,50 +453,26 @@ class XMLFilesReaderManager(object):
             ver = ver.capitalize()
             config.configVersion = ver
             self.log.debug("Data taking:", "%s" % datataking)
-            context = Context(datataking, config.configName)
-            conditions = [
-                BeamEnergyCondition(),
-                VeloCondition(),
-                MagneticFieldCondition(),
-                EcalCondition(),
-                HcalCondition(),
-                HltCondition(),
-                ItCondition(),
-                LoCondition(),
-                MuonCondition(),
-                OtCondition(),
-                Rich1Condition(),
-                Rich2Condition(),
-                Spd_prsCondition(),
-                TtCondition(),
-                VeloPosition(),
-            ]
-            for condition in conditions:
-                condition.interpret(context)
+            dtDescription = generateConditionDescription(datataking, config.configName)
+            self.log.debug(dtDescription)
+            datataking["Description"] = dtDescription
 
-            self.log.debug(context.getOutput())
-            datataking["Description"] = context.getOutput()
+            res = self.bkClient_._getDataTakingConditionId(dtDescription)
+            if not res["OK"]:
+                self.log.error(
+                    "Error retrieving the DataTaking Condition ID",
+                    f"Description: {dtDescription}. Error: {res['Message']}",
+                )
+                return res
 
-            res = self.bkClient_.getDataTakingCondDesc(datataking)
-            dataTackingPeriodDesc = None
-            if res["OK"]:
-                daqid = res["Value"]
-                if len(daqid) != 0:  # exist in the database datataking
-                    dataTackingPeriodDesc = res["Value"][0][0]
-                    self.log.debug("Data taking condition id", dataTackingPeriodDesc)
-                else:
-                    res = self.bkClient_.insertDataTakingCond(datataking)
-                    if not res["OK"]:
-                        return S_ERROR("DATA TAKING Problem:" + str(res["Message"]))
-                    dataTackingPeriodDesc = datataking["Description"]
-                    # The new data taking condition inserted. The name should be the generated name.
-            else:
-                # Note we allow to insert data quality tags when only the description is different.
-                res = self.bkClient_.insertDataTakingCond(datataking)
+            daqid = res["Value"]
+            # If there is no condition matching the description, create one
+            if daqid == -1:  # yes... -1 for non existing conditions
+                res = self.bkClient_.insertDataTakingCondDesc(dtDescription)
                 if not res["OK"]:
-                    return S_ERROR("DATA TAKING Problem:" + str(res["Message"]))
-                dataTackingPeriodDesc = datataking["Description"]
-                # The new data taking condition inserted. The name should be the generated name.
+                    self.log.error("Cannot insert DataTaking Condition Description", res["Message"])
+                    return res
+                daqid = res["Value"]
 
             # insert processing pass
             programName = None
@@ -577,7 +530,7 @@ class XMLFilesReaderManager(object):
             }
 
             self.log.debug("Pass_indexid", "%s" % steps)
-            self.log.debug("Data taking", "%s" % dataTackingPeriodDesc)
+            self.log.debug("Data taking", "%s" % dtDescription)
             self.log.debug("production", production)
 
             newJobParams = JobParameters()
@@ -591,7 +544,7 @@ class XMLFilesReaderManager(object):
             res = self.bkClient_.addProduction(
                 production,
                 simcond=None,
-                daq=dataTackingPeriodDesc,
+                daq=dtDescription,
                 steps=steps["Steps"],
                 inputproc="",
                 configName=config.configName,
@@ -636,7 +589,7 @@ class XMLFilesReaderManager(object):
 
         res = self.bkClient_.insertJob(attrList)
 
-        if not res["OK"] and production < 0:
+        if not res["OK"] and production is not None and production < 0:
             self.log.error("Failed inserting job", res["Message"])
             retVal = self.bkClient_.deleteProductionsContainer(production)
             if not retVal["OK"]:
