@@ -10,10 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Bookkeeping Command line interface."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
