@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Fix the luminosity of all descendants of a set of RAW files, if the run is finished."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
