@@ -13,12 +13,6 @@
 Returns metadata of the job step(s) that created a (list of) LFNs,
 or all steps for a (list of) JobID
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
