@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Retrieve from Bookkeeping information for a given run."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import DIRAC
 from DIRAC import gLogger, S_OK
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
