@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set the visibility flag to a dataset."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC import exit as dExit, gLogger
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
