@@ -16,9 +16,6 @@ Parameters:
    <run> : run number
    <flag> : flag to set
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 import DIRAC
 from DIRAC import gLogger
@@ -73,7 +70,7 @@ def main():
     processing = args[0].replace("/RealData", realData)
     if processing == "":
         processing = realData
-    run = args[1]
+    run = int(args[1])
     flag = args[2]
 
     # gLogger.error('Please wait for the OK from Stefan before actually flagging')
@@ -90,14 +87,13 @@ def main():
     #
     # Make sure it is a known processing pass
     #
-    irun = int(run)
 
     from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
     bkClient = BookkeepingClient()
-    res = bkClient.getRunInformations(irun)
+    res = bkClient.getRunInformations(run)
     if not res["OK"]:
-        gLogger.error("Cannot load the information for run %s" % (run))
+        gLogger.error("Cannot load the information for run %d" % run)
         gLogger.error(res["Message"])
         DIRAC.exit(2)
 
@@ -125,7 +121,7 @@ def main():
         print(res["Message"])
         DIRAC.exit(2)
     else:
-        print("Run %s RAW files flagged %s" % (run, flag))
+        print("Run %d RAW files flagged %s" % (run, flag))
 
     # Now the reconstruction and stripping processing passes
     for thisPass in recoPasses:
@@ -135,7 +131,7 @@ def main():
             print(res["Message"])
             DIRAC.exit(2)
         else:
-            print("Run %s Processing Pass %s flagged %s" % (run, thisPass, flag))
+            print("Run %d Processing Pass %s flagged %s" % (run, thisPass, flag))
 
     DIRAC.exit(0)
 
