@@ -13,10 +13,6 @@ workflow task.
 
 DIRAC assumes an execute() method will exist during usage.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import gLogger
 from LHCbDIRAC.Interfaces.API.LHCbJob import LHCbJob
 from LHCbDIRAC.Core.Utilities.ProductionData import preSubmissionLFNs
