@@ -14,13 +14,6 @@ current LHCb software versions.
 This is used by the production API to create production workflows but
 also provides lists of options files for test jobs.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
-
 import re
 from DIRAC import S_OK, gLogger
 
