@@ -10,18 +10,12 @@
 ###############################################################################
 """Resolve SE takes the workflow SE description and returns the list of
 destination storage elements for uploading an output file."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from random import shuffle
 
 from DIRAC import gLogger, gConfig
 from DIRAC.Core.Utilities.SiteSEMapping import getSEsForSite
 from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
 
-__RCSID__ = "$Id$"
-
 
 def _setLocalFirst(seList, localSEs):
     """return a shuffled list of SEs from seList, localSEs being first."""
