@@ -9,18 +9,14 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Utility for invoking running LHCb applications."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import asyncio
 import json
 import shlex
 import subprocess
 
 from DIRAC import gLogger, S_OK
+from DIRAC.Core.Utilities import DErrno
+from DIRAC.WorkloadManagementSystem.Utilities.RemoteRunner import RemoteRunner
 from LHCbDIRAC.Workflow.Modules.ModulesUtilities import getEventsToProduce
 
 
@@ -66,7 +62,7 @@ class RunApplication(object):
             gaudiAppModule.step_number,
         )
         self.applicationLog = gaudiAppModule.applicationLog or "applicationLog.txt"
-        self.stdError = gaudiAppModule.stdError
+        self.stdError = gaudiAppModule.stdError or self.applicationLog
 
         # Sanity checks
         if not gaudiAppModule.stepInputData and self.applicationName.lower() != "gauss":
@@ -83,10 +79,7 @@ class RunApplication(object):
                 "number_of_processors": gaudiAppModule.numberOfProcessors,
                 "version": gaudiAppModule.applicationVersion,
             },
-            "options": {
-                "files": commandOptions,
-                "processing_pass": gaudiAppModule.processingPass,
-            },
+            "options": {},
             "db_tags": {},
             "input": {
                 "files": ["LFN:" + sid for sid in gaudiAppModule.stepInputData],
@@ -107,10 +100,16 @@ class RunApplication(object):
         prodInfo["application"]["event_timeout"] = eventTimeout
 
         # options
-        if gaudiAppModule.optionsFormat:
-            prodInfo["options"]["format"] = gaudiAppModule.optionsFormat
-        if gaudiAppModule.extraOptionsLine:
-            prodInfo["options"]["gaudi_extra_options"] = gaudiAppModule.extraOptionsLine
+        if isinstance(commandOptions, dict):
+            # This is an lbexec style application
+            prodInfo["options"] = commandOptions
+        else:
+            prodInfo["options"]["files"] = commandOptions
+            prodInfo["options"]["processing_pass"] = gaudiAppModule.processingPass
+            if gaudiAppModule.optionsFormat:
+                prodInfo["options"]["format"] = gaudiAppModule.optionsFormat
+            if gaudiAppModule.extraOptionsLine:
+                prodInfo["options"]["gaudi_extra_options"] = gaudiAppModule.extraOptionsLine
 
         # db_tags
         if gaudiAppModule.DDDBTag:
@@ -177,32 +176,68 @@ class RunApplication(object):
         if self.applicationName == "Gauss" and self.usePrmon:
             command = [self.prmonPath, "--json-summary", "./prmon_Gauss.json", "--"] + command
         self.log.notice("Running command", shlex.join(command))
-        proc = await asyncio.create_subprocess_exec(
-            *command,
-            stdout=subprocess.PIPE,
-            stderr=subprocess.PIPE,
-        )
-        await asyncio.gather(
-            self._handleOutput(proc.stdout, self.applicationLog),
-            self._handleOutput(proc.stderr, self.stdError),
-            proc.wait(),
-        )
-        return (proc.returncode, proc.stdout, proc.stderr)
 
-    async def _handleOutput(self, stream, filename):
-        lines = []
-        try:
-            if filename:
-                log = open(filename, "at")
-            while line := await stream.readline():
-                line = line.decode(errors="backslashreplace")
-                lines += [line]
-                if "INFO Evt" in line or "Reading Event record" in line or "lb-run" in line:
-                    # These ones will appear in the std.out log too
-                    print(line.rstrip())
-                if filename:
-                    log.write(line)
-        finally:
-            if filename:
-                log.close()
-        return "".join(lines)
+        stdout = ""
+        stderr = ""
+        remoteRunner = RemoteRunner()
+        if remoteRunner.is_remote_execution():
+            outputDict = remoteRunner.execute(shlex.join(command))
+            if outputDict["OK"]:
+                returncode, stdout, stderr = outputDict["Value"]
+                self._handleRemoteOutput(stdout, self.applicationLog)
+                self._handleRemoteOutput(stderr, self.stdError)
+            else:
+                # Sometimes Errno has not been purposely defined and is equal to 0
+                returncode = outputDict["Errno"] if outputDict["Errno"] != 0 else DErrno.ERESGEN
+                stderr = outputDict["Message"]
+        else:
+            proc = await asyncio.create_subprocess_exec(
+                *command,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+            )
+            stdout_fh = None
+            if self.applicationLog:
+                stdout_fh = open(self.applicationLog, "at")
+
+            stderr_fh = None
+            if self.stdError == self.applicationLog:
+                stderr_fh = stdout_fh
+            elif self.stdError:
+                stderr_fh = open(self.applicationLog, "at")
+
+            try:
+                await asyncio.gather(
+                    self._handleOutput(proc.stdout, stdout_fh),
+                    self._handleOutput(proc.stderr, stderr_fh),
+                    proc.wait(),
+                )
+            finally:
+                if stdout_fh:
+                    stdout_fh.close()
+                if stderr_fh and stdout_fh != stderr_fh:
+                    stderr_fh.close()
+            returncode = proc.returncode
+        return (returncode, stdout, stderr)
+
+    async def _handleOutput(self, stream, fh):
+        """Process the output of a current local execution"""
+        while line := await stream.readline():
+            line = line.decode(errors="backslashreplace")
+            self._handleLine(line)
+            if fh:
+                fh.write(line)
+
+    def _handleRemoteOutput(self, lines, filename):
+        """Process the output of a remote execution"""
+        if filename:
+            with open(filename, "at") as log:
+                log.write(lines)
+        for line in lines.split("\n"):
+            self._handleLine(line)
+
+    def _handleLine(self, line):
+        """Print a given line to the standard output if related to an event"""
+        if "INFO Evt" in line or "Reading Event record" in line or "lb-run" in line:
+            # These ones will appear in the std.out log too
+            print(line.rstrip())
