@@ -10,10 +10,6 @@
 ###############################################################################
 """Takes an xmlSummary along with its IDs and creates a JSON file containing
 all the counters in the xmlSummary."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import json
 import xml.etree.ElementTree as ET
 from DIRAC import gLogger, S_ERROR, S_OK
