@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Utilities to check the XML summary files."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import ast
 import io
@@ -23,8 +19,6 @@ import xmltodict
 from DIRAC import gLogger
 from LHCbDIRAC.Core.Utilities.XMLTreeParser import XMLTreeParser
 
-__RCSID__ = "$Id$"
-
 
 def xmltojsonCat1(lCategory1):
     """returns a Category1 dictionary
