@@ -16,10 +16,6 @@
 :synopsis: RAWIntegrityAgent determines whether RAW files in CASTOR were migrated correctly.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # # imports
 import datetime
 
@@ -37,8 +33,6 @@ from DIRAC.Resources.Storage.StorageElement import StorageElement
 from LHCbDIRAC.DataManagementSystem.DB.RAWIntegrityDB import RAWIntegrityDB
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "DataManagement/RAWIntegrityAgent"
 
 
