@@ -15,10 +15,6 @@
 
 :synopsis: SEUsageAgent browses the SEs to determine their content and store it into a DB.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # # imports
 import os
 import time
@@ -42,8 +38,6 @@ from DIRAC.Interfaces.API.Dirac import Dirac
 from LHCbDIRAC.DataManagementSystem.Client.StorageUsageClient import StorageUsageClient
 from LHCbDIRAC.DataManagementSystem.DB.StorageUsageDB import StorageUsageDB
 
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "DataManagement/SEUsageAgent"
 
 
