@@ -12,10 +12,6 @@
 grouped by processing pass or other interesting parameters.
 
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import time
 import copy
@@ -37,8 +33,6 @@ from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClie
 from LHCbDIRAC.DataManagementSystem.Client.DataUsageClient import DataUsageClient
 from LHCbDIRAC.DataManagementSystem.Client.StorageUsageClient import StorageUsageClient
 
-__RCSID__ = "$Id$"
-
 
 def _standardDirectory(dirPath):
     """Add a "/" at the end of the directory name if not present"""
@@ -151,7 +145,7 @@ class StorageHistoryAgent(AgentModule):
 
             self.log.notice(
                 " User %s is using %.2f GiB (%s files)"
-                % (user, userCatalogData[user]["Size"] / (1024.0 ** 3), userCatalogData[user]["Files"])
+                % (user, userCatalogData[user]["Size"] / (1024.0**3), userCatalogData[user]["Files"])
             )
         self.log.notice("Sending %s records to accounting for user storage" % numRows)
         res = gDataStoreClient.commit()
