@@ -16,10 +16,6 @@
 :synopsis: StorageUsageAgent takes the FC as the primary source of information to
   determine storage usage.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # # imports
 import time
 import random
@@ -47,9 +43,6 @@ from DIRAC.ConfigurationSystem.Client.Helpers.Operations import Operations
 from LHCbDIRAC.DataManagementSystem.DB.StorageUsageDB import StorageUsageDB
 from LHCbDIRAC.DataManagementSystem.Client.StorageUsageClient import StorageUsageClient
 
-
-__RCSID__ = "$Id$"
-
 AGENT_NAME = "DataManagement/StorageUsageAgent"
 
 
