@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set of functions used by the DMS checking scripts."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import six
 from DIRAC import gLogger, S_OK
