@@ -11,10 +11,6 @@
 """DMScript is a class that creates default switches for DM scripts, decodes
 them and sets flags The module also provides a function for printing pretty
 results from DMS queries."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import six
 import sys
@@ -29,8 +25,6 @@ from DIRAC.DataManagementSystem.Utilities.DMSHelpers import resolveSEGroup
 from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import BKQuery
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
-__RCSID__ = "$Id$"
-
 
 def __printDictionary(dictionary, offset=0, shift=0, empty="Empty directory", depth=9999):
     """Dictionary pretty printing."""
