@@ -11,10 +11,6 @@
 """This is the Data Integrity Client which allows the simple reporting of
 problematic file and replicas to the IntegrityDB and their status correctly
 updated in the FileCatalog."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import re
 import six
 
@@ -27,8 +23,6 @@ from DIRAC.DataManagementSystem.Client.DataIntegrityClient import DataIntegrityC
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import ConsistencyChecks
 
-__RCSID__ = "$Id$"
-
 
 class DataIntegrityClient(DIRACDataIntegrityClient):
     def __init__(self):
