@@ -15,18 +15,12 @@
 
 :synopsis: Class that contains client access to the StorageUsageDB handler.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import six
 
 # # imports
 from DIRAC import S_ERROR
 from DIRAC.Core.Base.Client import Client, createClient
 
-__RCSID__ = "$Id$"
-
 
 @createClient("DataManagement/DataUsage")
 class DataUsageClient(Client):
