@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Set of functions used by the DMS scripts."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import sys
 import os
 import time
@@ -38,8 +34,6 @@ from LHCbDIRAC.DataManagementSystem.Client.DMScript import printDMResult, Progre
 from LHCbDIRAC.BookkeepingSystem.Client.ScriptExecutors import scaleSize
 from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import getProcessingPasses
 
-__RCSID__ = "$Id$"
-
 
 def __checkSEs(args, expand=True):
     """Finds StorageElements in a list of arguments and returns them separate
@@ -549,6 +543,10 @@ def executeAccessURL(dmScript):
                 for urlPrio, url in enumerate(urls, start=1):
                     urlElement = ET.SubElement(fileElement, "url")
                     urlElement.set("priority", str(urlPrio))
+                    # In InputDataResolution "mdf:" is prepended to the URL for RAW files however
+                    # this is a Gaudi specific hack makes the metalink file unusable
+                    if url.startswith("mdf:"):
+                        url = url[len("mdf:") :]
                     urlElement.text = url
 
                 # we could use the ElementTree.write method, but it is ugly,
@@ -1864,13 +1862,17 @@ def executeAddFile():
             exitCode = 3
             gLogger.error("Error: failed to upload %s to %s" % (localFile, lfnDict["SE"]), res["Message"])
         else:
-            if lfn in res["Value"]["Successful"]:
+            success = res["Value"]["Successful"].get(lfn, [])
+            if success and not ({"put", "register"} - set(success)):
                 gLogger.notice(
-                    "Successfully uploaded %s to %s (%.1f seconds)"
-                    % (localFile, lfnDict["SE"], res["Value"]["Successful"][lfn]["put"])
+                    "Successfully uploaded/registered %s to %s (%.1f/%.1f seconds)"
+                    % (localFile, lfnDict["SE"], success["put"], success["register"])
                 )
             else:
-                gLogger.error("Error: failed to upload %s to %s" % (lfn, lfnDict["SE"]), res["Value"]["Failed"][lfn])
+                gLogger.error(
+                    "Error: failed to upload file",
+                    "%s to %s:\n\t %s" % (lfn, lfnDict["SE"], res["Value"]["Failed"][lfn]),
+                )
         if remoteFile:
             os.remove(localFile)
 
@@ -2047,6 +2049,8 @@ def registerBK2FC(lfnList, seList, printResult=False):
     failed = res["Value"]["Failed"]
     bkMetadata = res["Value"]["Successful"]
     if failed:
+        if isinstance(failed, list):
+            failed = dict.fromkeys(failed, "Not in BK")
         gLogger.notice("%d files are not in the BK" % len(failed))
         result["Failed"].update(failed)
         lfnList = list(set(lfnList) - set(failed))
