@@ -16,10 +16,6 @@
 :synopsis: DISET interface to the RAWIntegrityDB.
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # imports
 import six
 
@@ -30,8 +26,6 @@ from DIRAC.Core.DISET.RequestHandler import RequestHandler
 # from LHCbDIRAC
 from LHCbDIRAC.DataManagementSystem.DB.RAWIntegrityDB import RAWIntegrityDB
 
-__RCSID__ = "$Id$"
-
 # global instance of the RAWIntegrityDB
 gRAWIntegrityDB = False
 
