@@ -15,10 +15,6 @@
 
 :synopsis: Implementation of the Storage Usage service in the DISET framework.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # imports
 import six
 
@@ -29,8 +25,6 @@ from DIRAC.Core.DISET.RequestHandler import RequestHandler
 # from LHCbDIRAC
 from LHCbDIRAC.DataManagementSystem.DB.StorageUsageDB import StorageUsageDB
 
-__RCSID__ = "$Id$"
-
 gStorageUsageDB = False
 
 
