@@ -9,8 +9,3 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """LHCbDIRAC.DataManagementSystem.Service package."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
