@@ -9,17 +9,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """This modules contains utility functions for LHCb DM."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import six
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Resources.Catalog.FileCatalogClient import FileCatalogClient
 
-__RCSID__ = "$Id$"
-
 
 def chown(directories, user=None, group=None, mode=None, recursive=False, ndirs=None, fcClient=None):
     """This method may change the user, group or mode of a directory and apply it
