@@ -8,10 +8,5 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 ############################################################
 """LHCbDIRAC.DataManagementSystem package."""
-__RCSID__ = "$Id$"
