@@ -11,11 +11,6 @@
 ###############################################################################
 """Create a new dataset replication or removal transformation according to
 plugin."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
 
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
@@ -46,6 +41,13 @@ def main():
     Script.registerSwitch("", "CheckMCReplication", "   List all MC replication transformations that are obsolete")
     Script.registerSwitch("", "ListProcessingPasses", "   Only lists the processing passes")
 
+    Script.registerSwitch(
+        "",
+        "BodyPlugin=",
+        "   BodyPlugin to use for the transformation",
+    )
+    Script.registerSwitch("", "TransBody=", "   Body to use for the transformation")
+
     Script.setUsageMessage(
         __doc__
         + "\n".join(
