@@ -10,12 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Retrieve a single file or list of files from Grid storage to the current directory."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
