@@ -11,12 +11,6 @@
 ###############################################################################
 """Remove replicas of a (list of) LFNs from all non-ARCHIVE storage
 elements."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
