@@ -9,10 +9,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import DIRAC
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
