@@ -8,10 +8,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # import mock
 # if mock.__version__ < '1.0.1':
 #   print 'Invalid Mock version %s !' % mock.__version__
