@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Get statistics on productions related to a given processing pass."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import DIRAC
 
 import datetime
@@ -31,8 +27,6 @@ from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClie
 from LHCbDIRAC.Core.Utilities.HTML import Table, TableCell, TableRow
 from LHCbDIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
 
-__RCSID__ = "$Id$"
-
 
 class HTMLProgressTable(object):
     def __init__(self, processingPass):
