@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test of the ProductionRequest and Production modules."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=line-too-long,invalid-name,protected-access,missing-docstring
 
 import unittest
