@@ -13,13 +13,6 @@
 
     Here we define a mapping which is taken from a list of log errors.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
-__RCSID__ = "$Id$"
-
 from DIRAC import S_OK, S_ERROR
 from DIRAC.Core.Base.ElasticDB import ElasticDB
 
