@@ -24,10 +24,6 @@
       - for the MC: just set pr.prodsToLaunch = [1]
       - for the merge and/or stripping: set pr.prodsToLaunch, then set pr.previousProdID
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from six.moves import range
 
 import ast
@@ -39,8 +35,6 @@ Script.parseCommandLine()
 from DIRAC import gConfig, gLogger, exit as DIRACexit
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import ProductionRequest
 
-__RCSID__ = "$Id$"
-
 #
 # Link compression level to the output file visibility. If any file types is visible, the corresponding
 # step takes the maximum compression level
