@@ -9,11 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Moving toward a templates-less system."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
 import ast
 
 from DIRAC.Core.Base import Script
@@ -23,9 +18,6 @@ Script.parseCommandLine()
 from DIRAC import gConfig, gLogger, exit as DIRACexit
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequest import ProductionRequest
 
-__RCSID__ = "$Id$"
-
-
 gLogger = gLogger.getSubLogger("LaunchingRequest_run.py")
 currentSetup = gConfig.getValue("DIRAC/Setup")
 
