@@ -9,15 +9,9 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """A module defining the state machine for the Productions."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.ResourceStatusSystem.PolicySystem.StateMachine import State, StateMachine
 
-__RCSID__ = "$Id$"
-
 
 class LHCbStateMachine(StateMachine):
     """Just redefining one method."""
