@@ -13,15 +13,9 @@
 TransferQualityPolicy.__bases__:
   DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase.PolicyBase
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK
 from DIRAC.ResourceStatusSystem.PolicySystem.PolicyBase import PolicyBase
 
-__RCSID__ = "$Id$"
-
 
 class TransferQualityPolicy(PolicyBase):
     """The TransferQualityPolicy class is a policy class to check the transfer
