@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Client for BookkeepingDB file catalog."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import six
 
 from DIRAC import gLogger, S_OK, S_ERROR
@@ -21,8 +17,6 @@ from DIRAC.Resources.Catalog.FileCatalogClientBase import FileCatalogClientBase
 from DIRAC.Resources.Catalog.Utilities import checkCatalogArguments
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
 
-__RCSID__ = "$Id$"
-
 
 class BookkeepingDBClient(FileCatalogClientBase):
     """File catalog client for bookkeeping DB."""
