@@ -13,16 +13,10 @@ add files to the RAW IntegrityDB.
 
 USED at OnLine
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from DIRAC import S_OK
 from DIRAC.Resources.Catalog.Utilities import checkCatalogArguments
 from DIRAC.Resources.Catalog.FileCatalogClientBase import FileCatalogClientBase
 
-__RCSID__ = "$Id$"
-
 
 class RAWIntegrityClient(FileCatalogClientBase):
 
