@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_Resources_Catalog_RAWIntegrityClient."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import mock
 import unittest
 
@@ -20,8 +16,6 @@ from six.moves import reload_module
 from DIRAC import gLogger
 import LHCbDIRAC.Resources.Catalog.RAWIntegrityClient as moduleTested
 
-__RCSID__ = "$Id$"
-
 ################################################################################
 
 
