@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """This is the LHCb Online storage."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from six.moves import xmlrpc_client as xmlrpclib
 import os
 
@@ -22,8 +18,6 @@ from DIRAC.Resources.Storage.StorageBase import StorageBase
 from DIRAC.Resources.Storage.Utilities import checkArgumentFormat
 from DIRAC.Core.Utilities.List import breakListIntoChunks
 
-__RCSID__ = "$Id$"
-
 
 class LHCbOnlineStorage(StorageBase):
     """Plugin to talk to the xmlrpc of the datamover."""
