@@ -9,17 +9,11 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_Resources_Storage_LHCbOnlineStorage."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import mock
 import unittest
 
 import LHCbDIRAC.Resources.Storage.LHCbOnlineStorage as moduleTested
 
-__RCSID__ = "$Id$"
-
 ################################################################################
 
 
