@@ -15,12 +15,6 @@
 
 :synopsis: clean up of finalised transformations
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import ast
 
 import six
