@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Minimal test for TransformationCleaningAgent."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import importlib
 import unittest
 
