@@ -9,10 +9,4 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """LHCbDIRAC.TransformationSystem.Client package."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 ################################################################################
