@@ -9,16 +9,10 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test_TS_Client_TaskManager."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import unittest
 
 import LHCbDIRAC.TransformationSystem.Client.TaskManager as moduleTested
 
-__RCSID__ = "$Id$"
-
 ################################################################################
 
 
