@@ -9,12 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """DISET request handler for the LHCbDIRAC/TransformationDB."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import six
 
 from DIRAC import S_OK, S_ERROR
