@@ -10,10 +10,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Does a TS -> BK check for processed files with descendants."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import sys
 import os
 import time
