@@ -19,12 +19,6 @@ Examples of Usage :
   dirac-production-set-run 1234 --EndRun 99000   (change endrun.)
   dirac-production-set-run 1234 --StartRun 99000 (change startrun.)
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import DIRAC
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
@@ -35,24 +29,24 @@ def main():
     from DIRAC.Core.Base import Script
 
     Script.setUsageMessage(
-        f"{__doc__}"
-        f"Usage:\n"
-        f"  {Script.scriptName} [option|cfgfile] ... Prod -Option [RunNumber|RunList]\n"
-        "Arguments:\n"
-        "  Prod:      DIRAC Production Id\n"
-        "  RunNumber: New Start or End run\n"
-        "  RunList: List of Runs to be added\n"
-        "Examples:\n"
-        "  # show the list of runs for transformation 92\n"
-        "  dirac-production-set-run.py 92 --List\n"
-        "  # add some discrete run to transformation 92\n"
-        "  dirac-production-set-run.py 92 --AddRuns 98200,98201\n"
-        "  # add some discrete run and a range of runs to transformation 92\n"
-        "  dirac-production-set-run.py 92 --AddRuns 98200,98201,99000:99100\n"
-        "  # change the start run for transformation 92\n"
-        "  dirac-production-set-run.py 92 --StartRun 98200\n"
-        "  # change the end run  for transformation 92\n"
-        "  dirac-production-set-run.py 92 --EndRun   98200\n"
+        __doc__
+        + "\n".join(
+            [
+                "Usage:",
+                "  %s [option|cfgfile] ... Prod -Option [RunNumber|RunList]" % Script.scriptName,
+                "Arguments:",
+                "  Prod:      DIRAC Production Id",
+                "  RunNumber: New Start or End run",
+                "  RunList: List of Runs to be added",
+                "Examples:\n",
+                "dirac-production-set-run.py 92 --List                        (show the list of runs for transformation 92)\n",
+                "dirac-production-set-run.py 92 --AddRuns 98200,98201             (add some discrete run to transformation 92)\n",
+                "dirac-production-set-run.py 92 --AddRuns 98200,98201,99000:99100 (add some discrete run and\
+         a range of runs to transformation 92)\n",
+                "dirac-production-set-run.py 92 --StartRun 98200                 (change the start run for transformation 92)\n",
+                "dirac-production-set-run.py 92 --EndRun   98200                 (change the end run  for transformation 92)\n",
+            ]
+        )
     )
 
     Script.registerSwitch("", "EndRun=", "Specify endrun for the transformation")
