@@ -12,12 +12,6 @@
 """Move files that are Unused or MaxReset from a parent production to its
 derived production The argument is a list of productions: comma separated list
 of ranges (a range has the form p1:p2)"""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC.Core.Utilities.DIRACScript import DIRACScript
 
 
