@@ -15,16 +15,11 @@ step_commons dictionary can be utilized.
 Since not all projects are instrumented to work with the AppConfig error
 suite any failures will not be propagated to the workflow.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 
 from DIRAC import S_OK, S_ERROR, gLogger
 
+import LHCbDIRAC
 import LHCbDIRAC.Core.Utilities.LogErr as LogErr
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
@@ -39,7 +34,7 @@ class ErrorLogging(ModuleBase):
         self.log = gLogger.getSubLogger("ErrorLogging")
         super(ErrorLogging, self).__init__(self.log)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
         # Internal parameters
         self.errorLogNameHTML = ""
         self.errorLogNamejson = ""
