@@ -9,20 +9,15 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Simple merging module for MDF files."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import shlex
 
 from DIRAC import S_OK, S_ERROR, gLogger
 from DIRAC.Core.Utilities.Subprocess import systemCall
 from DIRAC.Resources.Catalog.PoolXMLCatalog import PoolXMLCatalog
 
+import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 
-__RCSID__ = "$Id$"
-
 
 class MergeMDF(ModuleBase):
     """To be used in normal workflows."""
@@ -33,7 +28,7 @@ class MergeMDF(ModuleBase):
         self.log = gLogger.getSubLogger("MergeMDF")
         super(MergeMDF, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
 
         self.outputLFN = ""
         # List all input parameters here
