@@ -10,12 +10,6 @@
 ###############################################################################
 """UploadLogFile module is used to upload the files present in the working
 directory."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import shutil
 import glob
@@ -32,6 +26,7 @@ from DIRAC.RequestManagementSystem.Client.File import File
 from DIRAC.Resources.Storage.StorageElement import StorageElement
 from DIRAC.Core.Utilities.ReturnValues import returnSingleResult
 
+import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.Workflow.Modules.ModulesUtilities import zipFiles
 from LHCbDIRAC.Core.Utilities.ProductionData import getLogPath
@@ -49,7 +44,7 @@ class UploadLogFile(ModuleBase):
         self.log = gLogger.getSubLogger("UploadLogFile")
         super(UploadLogFile, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
 
         self.logSE = self.opsH.getValue("LogStorage/LogSE", "LogSE")
         self.logSizeLimit = self.opsH.getValue("LogFiles/SizeLimit", 1 * 1024 * 1024)
