@@ -9,18 +9,14 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """UploadMC module is used to upload to ES the json files for MC statistics."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import io
 import json
 
 import six
 from DIRAC import S_OK, S_ERROR, gLogger
+
+import LHCbDIRAC
 from LHCbDIRAC.Workflow.Modules.ModuleBase import ModuleBase
 from LHCbDIRAC.ProductionManagementSystem.Client.MCStatsClient import MCStatsClient
 from LHCbDIRAC.Core.Utilities.XMLSummaries import XMLSummary
@@ -36,7 +32,7 @@ class UploadMC(ModuleBase):
         self.log = gLogger.getSubLogger("UploadMC")
         super(UploadMC, self).__init__(self.log)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
 
     def _resolveInputVariables(self):
         """standard method for resolving the input variables."""
