@@ -10,12 +10,6 @@
 ###############################################################################
 """Module to upload specified job output files according to the parameters
 defined in the production workflow."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 import os
 import random
 import glob
@@ -30,6 +24,7 @@ from DIRAC.RequestManagementSystem.Client.Operation import Operation
 from DIRAC.RequestManagementSystem.Client.File import File
 from DIRAC.Resources.Catalog.FileCatalog import FileCatalog
 
+import LHCbDIRAC
 from LHCbDIRAC.Core.Utilities.ResolveSE import getDestinationSEList
 from LHCbDIRAC.Core.Utilities.ProductionData import constructProductionLFNs
 from LHCbDIRAC.DataManagementSystem.Client.ConsistencyChecks import getFileDescendants
@@ -48,7 +43,7 @@ class UploadOutputData(ModuleBase):
         self.log = gLogger.getSubLogger("UploadOutputData")
         super(UploadOutputData, self).__init__(self.log, bkClientIn=bkClient, dm=dm)
 
-        self.version = __RCSID__
+        self.version = LHCbDIRAC.version
         self.commandTimeOut = 10 * 60
         self.jobID = ""
         self.existingCatalogs = []
