@@ -9,10 +9,6 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """just some common components for tests."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 from mock import MagicMock
 
 from DIRAC.RequestManagementSystem.Client.Request import Request
