@@ -9,14 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Test class for ModuleBase."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access, missing-docstring, invalid-name
-
-__RCSID__ = "$Id$"
-
 import os
 from itertools import product
 from mock import MagicMock
