@@ -9,14 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit tests for Workflow Module UploadMC."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access, missing-docstring, invalid-name, line-too-long
-
-__RCSID__ = "$Id$"
-
 from itertools import product
 
 from mock import MagicMock
