@@ -9,14 +9,7 @@
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
 """Unit tests for Workflow Module Uploads."""
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 # pylint: disable=protected-access, missing-docstring
-
-__RCSID__ = "$Id$"
-
 import os
 import copy
 import json
