@@ -12,12 +12,6 @@
 
 Extends the DIRAC JobDB with minor things
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-__RCSID__ = "$Id$"
-
 from DIRAC import S_OK
 from DIRAC.Core.Utilities import Time
 
