@@ -17,10 +17,6 @@
 
    The distributed data production and analysis system of LHCb.
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 
 from pkg_resources import get_distribution, DistributionNotFound
