@@ -10,10 +10,6 @@
 ###############################################################################
 """ Collection of user jobs for testing purposes
 """
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import os
 import time
 import errno
